@@ -70,6 +70,7 @@ def load_configuration(config: str, debug: bool) -> typing.Tuple[dict, dict]:
     http_settings = config.get('http', {})
     ldap = config.get('ldap', {})
     postgres = config.get('postgres', {})
+    sentry = config.get('sentry', {})
     session = config.get('session', {})
     stats = config.get('stats', {})
 
@@ -104,6 +105,8 @@ def load_configuration(config: str, debug: bool) -> typing.Tuple[dict, dict]:
         'postgres_connection_timeout': postgres.get('connection_timeout'),
         'postgres_connection_ttl': postgres.get('connection_ttl'),
         'postgres_query_timeout': postgres.get('query_timeout'),
+        'sentry_backend_dsn': sentry.get('backend_dsn', False),
+        'sentry_ui_dsn': sentry.get('ui_dsn', False),
         'server_header': 'imbi/{}'.format(version),
         'session_duration': int(session.get('duration', '7')),
         'session_pool_size': session.get('pool_size', 10),
